%define major   3
%define minor   3
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:           assimp
Version:        3.3.1
Release:        %mkrel 5
Summary:        Library to import various 3D model formats into applications
Group:          Graphics/3D
License:        BSD
URL:            http://www.assimp.org
Source0:        https://github.com/assimp/assimp/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:         assimp-3.3.1-mga-fdr-system-poly2tri-clipper.patch
Patch1:         assimp-3.3.1-mga-system-unzip.patch
# Fix library and include paths in assimp-config.cmake
# Fixes rhbz#1263698, not submitted upstream
# Rehashed to 3.3.1
Patch2:         0001-Assimp-cmake-provider-fix.patch
Patch10:        assimp-3.3.1-install-pkgconfig.patch
# Upstream backports:
# Collada morph animation
Patch100:       0001-Morph-animation-support-for-collada.patch

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(poly2tri)
# assimp 3.1 seems not to build with the most recent version of polyclipping
#BuildRequires:  pkgconfig(polyclipping)
BuildRequires:  pkgconfig(zlib)

%description
Assimp, the Open Asset Import Library, is a free library to import various
well-known 3D model formats into applications. Assimp aims to provide a full
asset conversion pipeline for use in game engines and real-time rendering
systems, but is not limited to these applications.

This package contains the assimp binary, a tool to work with various formats.

%files
%{_bindir}/%{name}

#----------------------------------------------------------------------------

%package -n     %{libname}
Summary:        Library to import various 3D model formats into applications
Group:          System/Libraries

%description -n %{libname}
Assimp, the Open Asset Import Library, is a free library to import various
well-known 3D model formats into applications. Assimp aims to provide a full
asset conversion pipeline for use in game engines and real-time rendering
systems, but is not limited to these applications.

%files -n       %{libname}
%doc Readme.md LICENSE CREDITS CHANGES
%{_libdir}/lib%{name}.so.%{major}{,.*}

#----------------------------------------------------------------------------

%package -n     %{devname}
Summary:        Header files and development libraries for assimp
Group:          Development/C++
Provides:       %{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n %{devname}
This package contains the header files and development libraries for assimp.
You need to install it if you want to develop programs using assimp.

%files -n       %{devname}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/cmake/%{name}-%{major}.%{minor}
%{_libdir}/pkgconfig/%{name}.pc

#----------------------------------------------------------------------------

%prep
%setup -q
%autopatch -p1

# Get rid of bundled libs so we can't accidentally build against them
#rm -rf contrib/clipper
rm -rf contrib/cppunit-1.12.1
rm -rf contrib/poly2tri
rm -rf contrib/unzip
rm -rf contrib/zlib

dos2unix CHANGES CREDITS LICENSE Readme.md

%build
%cmake -DASSIMP_BUILD_TESTS=NO \
       -DASSIMP_LIB_INSTALL_DIR=%{_libdir} \
       -DASSIMP_BIN_INSTALL_DIR=%{_bindir} \
       -DASSIMP_INCLUDE_INSTALL_DIR=%{_includedir} \
       -DPOLY2TRI_LIB_PATH=%{_libdir} \
       -DPOLY2TRI_INCLUDE_PATH=%{_includedir}/poly2tri
# To use system polyclipping if assimp ever becomes compatible:
#       -DCLIPPER_LIB_PATH=%%{_libdir} \
#       -DCLIPPER_INCLUDE_PATH=%%{_includedir}/polyclipping
%cmake_build

%install
%cmake_install


%changelog
* Sat Feb 15 2020 umeabot <umeabot> 3.3.1-5.mga8
+ Revision: 1526508
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon Jun 03 2019 akien <akien> 3.3.1-4.mga7
+ Revision: 1399526
- Drop doc package, does not build and not really useful

* Fri Sep 21 2018 umeabot <umeabot> 3.3.1-3.mga7
+ Revision: 1294997
- Mageia 7 Mass Rebuild

* Fri Aug 11 2017 daviddavid <daviddavid> 3.3.1-2.mga7
+ Revision: 1139804
- backport some patches from fedora (this should fix qt3d build against assimp system)
- add a doc subpackage

* Sat Oct 29 2016 akien <akien> 3.3.1-1.mga6
+ Revision: 1063933
- Version 3.3.1

* Mon Jul 11 2016 akien <akien> 3.2-3.mga6
+ Revision: 1041066
- Fix debug postfix in cmake config files

* Sun Apr 24 2016 akien <akien> 3.2-2.mga6
+ Revision: 1005874
- Build against new poly2tri

* Wed Jan 13 2016 akien <akien> 3.2-1.mga6
+ Revision: 922902
- Version 3.2

* Wed Oct 15 2014 umeabot <umeabot> 3.1.1-3.mga5
+ Revision: 746314
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.1.1-2.mga5
+ Revision: 678000
- Mageia 5 Mass Rebuild

* Mon Jun 23 2014 akien <akien> 3.1.1-1.mga5
+ Revision: 638765
- Version 3.1.1

* Wed Jun 11 2014 akien <akien> 3.1-2.mga5
+ Revision: 635664
- Revert enabling the build with system-wide polyclipping, our version is too recent
- Use system-wide polyclipping instead of embedded clipper.hpp

* Mon Jun 09 2014 akien <akien> 3.1-1.mga5
+ Revision: 635262
- Use newly packaged system-wide poly2tri
- Version 3.1

* Thu Jun 05 2014 akien <akien> 3.0.1270-1.mga5
+ Revision: 633526
- Generate HTML documentation (patch)
- Use system minizip (patch)
- import source RPM from OpenMandriva

